@@ -9,10 +9,8 @@ VERSION_HEADER = "API-version"
 
 SCOPE_NOTIFICATIES_PUBLICEREN_LABEL = "notificaties.scopes.publiceren"
 
-# see https://docs.nlx.io/further-reading/transaction-logs/
-HEADER_APPLICATION = "X-NLX-Request-Application-Id"
-HEADER_USER_ID = "X-NLX-Request-User-Id"
 HEADER_AUDIT = "X-Audit-Toelichting"
+HEADER_LOGRECORD_ID = "X-NLX-Logrecord-ID"
 
 FILTER_URL_DID_NOT_RESOLVE = "NO_MATCHING_OBJECT"
 
